Module blaxel.core.client.models.configuration
==============================================

Classes
-------

`Configuration(continents: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, countries: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, private_locations: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, regions: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>)`
:   Configuration
    
    Attributes:
        continents (Union[Unset, list[Any]]): Continents
        countries (Union[Unset, list[Any]]): Countries
        private_locations (Union[Unset, list[Any]]): Private locations managed with blaxel operator
        regions (Union[Unset, list[Any]]): Regions
    
    Method generated by attrs for class Configuration.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `continents: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `countries: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `private_locations: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `regions: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :